@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: hscolour
-version: 1.19
-id: hscolour-1.19-979f77aca95a6c455e6419904dcd7046
+version: 1.20.3
+id: hscolour-1.20.3-6e77e26e0faf4aef6b930f12274e936e
 
 license: GPL
-copyright: 2003-2011 Malcolm Wallace, University of York; 2006 Bjorn Bringert
+copyright: 2003-2012 Malcolm Wallace; 2006 Bjorn Bringert
 maintainer: Malcolm Wallace
 stability:
 homepage: http://code.haskell.org/~malcolm/hscolour/
 package-url:
+synopsis: Colourise Haskell code.
 description: hscolour is a small Haskell script to colourise Haskell code. It currently
              has six output formats:
              ANSI terminal codes (optionally XTerm-256colour codes),
@@ -33,20 +34,21 @@ exposed-modules: Language.Haskell.HsColour
                  Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
                  Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/hscolour-1.19
-library-dirs: /usr/local/lib/ghc/hscolour-1.19
-hs-libraries: HShscolour-1.19
+trusted: False
+import-dirs: /usr/local/lib/ghc/hscolour-1.20.3
+library-dirs: /usr/local/lib/ghc/hscolour-1.20.3
+hs-libraries: HShscolour-1.20.3
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         containers-0.4.0.0-f1307d32d8f4b51a1487c01f0997b6d9
+depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
+         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-hscolour-1.19/html/hscolour.haddock
-haddock-html: /usr/local/share/doc/hs-hscolour-1.19/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-hscolour-1.20.3/html/hscolour.haddock
+haddock-html: /usr/local/share/doc/hs-hscolour-1.20.3/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
